@@ -187,29 +187,6 @@ class JWindow(QMainWindow):
             self.set_window_to_corner()
 
 
-class JCancelConfirmDialog(QWidget):
-    """ #### Imports: from JAK.Widgets import JCancelConfirmDialog """
-    def __init__(self, parent, title, msg, on_confirm):
-        """
-        * :param parent: Parent window
-        * :param window_title:str
-        * :param msg:str
-        * :param on_confirm: Function to execute use parenthesis ()
-        """
-        super().__init__(parent)
-        reply = QMessageBox.question(self, title, msg, QMessageBox.Yes | QMessageBox.No, QMessageBox.No)
-        self.setAttribute(Qt.WA_DeleteOnClose, True)
-        self.setWindowTitle(title)
-        view = Instance.retrieve("view")
-        if view:
-            self.setWindowIcon(view.icon())
-        if reply == QMessageBox.Yes:
-            on_confirm()
-        else:
-            self.destroy()
-        self.show()
-
-
 class JToolbar(QToolBar):
     """ #### Imports: from JAK.Widgets import JToolbar """
     def __init__(self, parent, toolbar, icon, title):
@@ -244,7 +221,7 @@ class JToolbar(QToolBar):
             return lambda: view.setUrl(QUrl(url))
         else:
             msg = url
-            return lambda: InfoDialog(self, title, msg)
+            return lambda: Dialog.information(self, title, msg)
 
 
 class Menu(QMenuBar):
@@ -321,22 +298,19 @@ class Menu(QMenuBar):
             return lambda: IPC.Communication.send(url)
         else:
             msg = url
-            return lambda: InfoDialog(self, title, msg)
-        
+            return lambda: Dialog.information(self, title, msg)
 
-class InfoDialog(QWidget):
-    """ #### Imports: from JAK.Widgets import InfoDialog """
-    def __init__(self, parent, title, msg):
-        """
-        * :param parent: Parent window
-        * :param msg:str
-        * :param on_confirm: Function to execute omit parenthesis ()
-        """
-        super().__init__()
-        self.setAttribute(Qt.WA_DeleteOnClose, True)
-        self.setWindowTitle(title)
-        QMessageBox.information(parent, title, msg, QMessageBox.Ok)
-        self.show()
+
+class Dialog:
+    @staticmethod
+    def question(parent, title, msg, on_confirm=""):
+        reply = QMessageBox.question(parent, title, msg, QMessageBox.Yes | QMessageBox.No, QMessageBox.No)
+        if reply == QMessageBox.Yes:
+            on_confirm()
+
+    @staticmethod
+    def information(parent, title, msg):
+        QMessageBox.information(parent, title, msg)
 
 
 class FileChooserDialog(QWidget):
@@ -356,3 +330,6 @@ class FileChooserDialog(QWidget):
             options=options)
         if file_name[0]:
             return file_name[0]
+
+        self.hide()
+        self.destroy() 
